<?php

App::uses('AppModel', 'Model');

/**
 * BuzzSourceAppModel extended by API models from individual plugins.
 */
class BuzzSourceAppModel extends AppModel {

	public $useTable = false;

	/**
	 * The name of the DataSource connection that this Model uses (this is set in
	 * the constructor so that we can use the app's config from bootstrap).
	 *
	 * @var string
	 */
	public $useDbConfig = null;

	protected $_apiRequests = [];

	protected $_apiResponses = [];

	public function __construct($id = false, $table = null, $ds = null) {
		$this->useDbConfig = Configure::read('api.default');
		parent::__construct($id, $table, $ds);
	}

	public function find($type = 'first', $query = []) {
		if (!empty($query['method'])) {
			$apiRequest = $query['method'];
			if (!empty($query['conditions'])) {
				$apiRequest = http_build_query($query['conditions']);
			}
			$this->_apiRequests[] = $apiRequest;
		}
		$results = parent::find($type, $query);
		if (!empty($query['method'])) {
			$this->_apiResponses[] = $results;
		}
		return $results;
	}

	/**
	 * Returns a date in the European format to the SQL format.
	 *
	 * @param string $date European date format (e.g. 30/6/2015)
	 * @return string SQL format date (e.g. 2015-06-30)
	 */
	public static function dateToSqlFormat($date) {
		if (preg_match('|(\d{1,2})[/-](\d{1,2})[/-](\d{4})|', $date, $parts) === 1) {
			return $parts[3] . '-' . str_pad($parts[2], 2, '0', STR_PAD_LEFT) . '-' . str_pad($parts[1], 2, '0', STR_PAD_LEFT);
		}
		return null;
	}

	/**
	 * Returns a UNIX timestamp from a European date format.
	 *
	 * @param string $date European date format (e.g. 30/6/2015)
	 * @return int Unix timestamp
	 */
	public static function dateToTime($date) {
		if (preg_match('|(\d{1,2})[/-](\d{1,2})[/-](\d{4})( (\d{1,2}):(\d{1,2}))?|', $date, $parts) === 1) {

			$hour = 0;
			$mins = 0;
			if (!empty($parts[4])) {
				$hour = $parts[5];
				$mins = $parts[6];
			}

			return mktime($hour, $mins, 0, $parts[2], $parts[1], $parts[3]);
		}
		return null;
	}

	public function getApiResponses() {
		return array_combine($this->_apiRequests, $this->_apiResponses);
	}

}
