<?php
App::uses('HttpSocket', 'Network/Http');
App::uses('DataSource', 'Model/Datasource');

class BuzzSource extends DataSource {

	protected $_schema = [];

	public function __construct($config) {
		parent::__construct($config);
		$this->Http = new HttpSocket();
	}

	public function describe($model) {
		return $this->_schema;
	}

	public function read(Model $model, $queryData = array(), $recursive = null) {
		$json = $this->Http->get(
			$this->config['host'] . '/' . $queryData['method'],
			$queryData['conditions']
		);

		$response = json_decode($json, true);

		// Log the API call.
		$this->_logApiCall(
			$this->config['host'] . '/' . $queryData['method'],
			!empty($queryData['conditions']) ? $queryData['conditions'] : [],
			$json,
			isset($queryData['debug']) ? $queryData['debug'] : 1
		);

		if (is_null($response)) {
			$error = json_last_error();
			throw new CakeException($error);
		}

		return [$model->alias => $response];
	}

	/**
	 * Logs API calls
	 *
	 * @param string $url
	 * @param array $params
	 * @param string $data
	 * @param int $debugLevel Level for debugging use 1 to always log and 2 to only log when full debug enabled
	 * @return void
	 */
	protected function _logApiCall($url, array $params, $data, $debugLevel = 1) {
		if ($debugLevel > 0) {
			$debug = Configure::read('api.debug');
			if (!empty($debug) && $debug >= $debugLevel) {
				$this->log($url, 'api');
				$this->log($params, 'api');
				$this->log($data, 'api');
			}
		}
		return;
	}

}
